import { Component, OnInit, ViewChild } from '@angular/core';
import { Recipe } from '../models/recipe';
import { Router } from '@angular/router';
import { CommonModule } from '@angular/common';
import { MatTableModule, MatTableDataSource } from '@angular/material/table';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import { MatButtonModule } from '@angular/material/button';

@Component({
  selector: 'app-recipe-list',
  standalone: true,
  templateUrl: './recipe-list.component.html',
  styleUrls: ['./recipe-list.component.scss'],
  imports: [CommonModule, MatTableModule, MatPaginatorModule, MatButtonModule],
})
export class RecipeListComponent implements OnInit {
  recipes: Recipe[] = [];
  dataSource: MatTableDataSource<Recipe> = new MatTableDataSource<Recipe>();
  displayedColumns: string[] = ['name', 'description', 'image', 'actions'];

  @ViewChild(MatPaginator) paginator!: MatPaginator;

  constructor(private router: Router) {}

  ngOnInit(): void {
    this.recipes = JSON.parse(localStorage.getItem('recipes') || '[]');
    this.dataSource.data = this.recipes;
  }

  ngAfterViewInit() {
    this.dataSource.paginator = this.paginator;
  }

  getQuantity(recipeId: number, ingredientId: number): number {
    const recipe = this.recipes.find((r) => r.id === recipeId);
    const ingredientRecipe = recipe?.ingredients.find(
      (i) => i.id === ingredientId
    );
    return ingredientRecipe
      ? this.getIngredientQuantity(recipeId, ingredientId)
      : 0;
  }

  getIngredientQuantity(recipeId: number, ingredientId: number): number {
    // Implémenter la logique pour retourner la quantité d'ingrédient
    return 0;
  }

  navToAddRecipe(): void {
    this.router.navigate(['/add']);
  }

  onSelectRecipe(recipe: Recipe): void {
    this.router.navigate(['/recipe', recipe.id]);
  }
}
